# TODOs, issues, and planned features
* Handle hijack using URLs on non-unique email addresses.
* Store info in user's profile (see #3 comments, Use case: 'Notify users when they were hijacked')
* Graceful support for custom user models that do not feature username / email

# Similar projects
Similar projects can be found and compared in the [user-switching](https://www.djangopackages.com/grids/g/user-switching/) or the [support](https://www.djangopackages.com/grids/g/support-apps/) grids at Django Packages.


# Contributing
Anyone and everyone is welcome to contribute. Please take a moment to review the [guidelines for contributing](https://github.com/arteria/django-hijack/blob/master/CONTRIBUTING.md).
